## Kinematics library

This package contains several functions to perform attitude transformations.

## Requirements

* pytest
* numpy

## TODO

- [ ] Implement all of the Euler Angles
- [ ] All euler angle rates

